@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2012 Olivier Girondel
+ *  Copyright 1994-2013 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -43,50 +43,58 @@ static char *data = NULL;
 static void
 init()
 {
-  printf("[+] using %s as capture device\n", pcm_name);
+  VERBOSE(printf("[+] using %s as capture device\n", pcm_name));
 
   snd_pcm_hw_params_alloca(&hwparams);
 
   if (snd_pcm_open(&pcm_handle, pcm_name, stream, 0) < 0)
     xerror("error opening PCM device %s\n", pcm_name);
-  else
-    printf("[+] %s ready for capture\n", pcm_name);
+  else {
+    VERBOSE(printf("[+] %s ready for capture\n", pcm_name));
+  }
 
   if (snd_pcm_hw_params_any(pcm_handle, hwparams) < 0)
     xerror("error configuring PCM device %s\n", pcm_name);
-  else
-    printf("[+] %s configured\n", pcm_name);
+  else {
+    VERBOSE(printf("[+] %s configured\n", pcm_name));
+  }
 
   if (snd_pcm_hw_params_set_access(pcm_handle, hwparams, SND_PCM_ACCESS_RW_INTERLEAVED) < 0)
     xerror("error setting access mode\n");
-  else
-    printf("[+] access mode set\n");
+  else {
+    VERBOSE(printf("[+] access mode set\n"));
+  }
 
   if (snd_pcm_hw_params_set_format(pcm_handle, hwparams, SND_PCM_FORMAT_S16_LE) < 0)
     xerror("error setting format\n");
-  else
-    printf("[+] format set\n");
+  else {
+    VERBOSE(printf("[+] format set\n"));
+  }
 
   exact_rate = rate;
   if (snd_pcm_hw_params_set_rate_near(pcm_handle, hwparams, &exact_rate, 0) < 0)
     xerror("error setting rate\n");
-  else
-    printf("[+] setting format: wanted %dHz, got %dHz\n", rate, exact_rate);
+  else {
+    VERBOSE(printf("[+] setting format: wanted %dHz, got %dHz\n", rate, exact_rate));
+  }
 
   if (snd_pcm_hw_params_set_channels(pcm_handle, hwparams, 2) < 0)
     xerror("error setting channels\n");
-  else
-    printf("[+] channels set\n");
+  else {
+    VERBOSE(printf("[+] channels set\n"));
+  }
 
   if (snd_pcm_hw_params_set_period_size_near(pcm_handle, hwparams, &frames, &dir) < 0)
     xerror("error setting period size");
-  else
-    printf("[+] period size set\n");
+  else {
+    VERBOSE(printf("[+] period size set\n"));
+  }
 
   if (snd_pcm_hw_params(pcm_handle, hwparams) < 0)
     xerror("error setting HW params\n");
-  else
-    printf("[+] HW params set\n");
+  else {
+    VERBOSE(printf("[+] HW params set\n"));
+  }
 
   /* Use a buffer large enough to hold one period */
   snd_pcm_hw_params_get_period_size(hwparams, &frames, &dir);
