@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2012 Olivier Girondel
+ *  Copyright 1994-2013 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -63,8 +63,9 @@ create(Context_t *ctx)
 
   if (NULL == file)
     xerror("sndfile: no BINIOU_SNDFILE environment variable specified !\n");
-  else
-    printf("[i] Reading file '%s'\n", file);
+  else {
+    VERBOSE(printf("[i] Reading file '%s'\n", file));
+  }
 
   loop_env = getenv("BINIOU_SNDFILE_LOOP");
   if (NULL != loop_env)
@@ -140,7 +141,7 @@ run(Context_t *ctx)
       frames = sfi.frames;
     } else {
       ctx->running = 0;
-      printf("[i] sndfile: end of stream '%s'\n", file);
+      VERBOSE(printf("[i] sndfile: end of stream '%s'\n", file));
     }
   }
 }
