@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2012 Olivier Girondel
+ *  Copyright 1994-2013 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -119,7 +119,7 @@ compute_generate_vector_field(VectorField_t *vf)
 
   height = (guint32)vf->vector_field->height;
 
-  printf("[i] infinity: Launching threads\n");
+  VERBOSE(printf("[i] infinity: Launching threads\n"));
   for (f = 0; f < vf->nb_fct; f++) {
     struct args_s *args = xcalloc(1, sizeof(struct args_s));
 
@@ -130,13 +130,13 @@ compute_generate_vector_field(VectorField_t *vf)
     pthread_create(&threads[f], NULL, (void *(*)(void *))compute_generate_vector_field_loop, (void *)args);
   }
 
-  printf("[i] infinity: Waiting for threads: ");
+  VERBOSE(printf("[i] infinity: Waiting for threads: "));
   for (f = 0; f < vf->nb_fct; f++) {
     pthread_join(threads[f], NULL);
-    printf("%d ", f);
+    VERBOSE(printf("%d ", f));
     fflush(stdout);
   }
-  printf("\n[i] infinity: All threads exited\n");
+  VERBOSE(printf("\n[i] infinity: All threads exited\n"));
   fflush(stdout);
 
   xfree(threads);
