@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2012 Olivier Girondel
+ *  Copyright 1994-2013 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -70,7 +70,9 @@ ok(__attribute__ ((unused)) Context_t *ctx)
   if ((p == WIDTH) || (p == HEIGHT) || (p == 1))
     return 0;
 
+#ifdef DEBUG
   printf("[i] mosaic: max_size= %d\n", max_size);
+#endif
     
   return 1;
 }
@@ -82,7 +84,7 @@ create(Context_t *ctx)
   if (ok(ctx))
     on_switch_on(ctx);
   else {
-    printf("[!] mosaic: non-standard screen size, disabling plugin.\n");
+    VERBOSE(printf("[!] mosaic: non-standard screen size, disabling plugin.\n"));
     options |= BEQ_DISABLED;
   }
 }
