@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2012 Olivier Girondel
+ *  Copyright 1994-2013 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -193,15 +193,16 @@ set_random_visible()
 {
   int i;
 
-  printf("[r] Building rotors: ");
+  VERBOSE(printf("[r] Building rotors: "));
   for (i = 0; i < nb_rotors; i++)  {
     tab[i].visible = (drand48() <= proba_visible);
-    if (tab[i].visible)
-      printf("+");
-    else
-      printf("-");
+    if (tab[i].visible) {
+      VERBOSE(printf("+"));
+    } else {
+      VERBOSE(printf("-"));
+    }
   }
-  printf(" done\n");
+  VERBOSE(printf(" done\n"));
 }
 
 
