@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2012 Olivier Girondel
+ *  Copyright 1994-2013 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -54,7 +54,7 @@ create(__attribute__ ((unused)) Context_t *ctx)
 
   rnd = g_rand_new();
 
-  printf("[i] Ouh-ouuuh! \\o/ Le Touw Eiffel !!\n");
+  VERBOSE(printf("[i] Ouh-ouuuh! \\o/ Le Touw Eiffel !!\n"));
 }
 
 
