@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2012 Olivier Girondel
+ *  Copyright 1994-2013 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -46,8 +46,8 @@ open_rtmp()
   if (NULL == (rtmp = popen(cmd, "w")))
     xperror("RTMP:popen");
   else {
-    printf("[i] RTMP: opened stream to %s\n", url);
-    printf("[i] RTMP: ffmpeg args: '%s'\n", args);
+    VERBOSE(printf("[i] RTMP: opened stream to %s\n", url));
+    VERBOSE(printf("[i] RTMP: ffmpeg args: '%s'\n", args));
   }
 }
 
@@ -77,7 +77,7 @@ run(Context_t *ctx)
     size_t res;
 
     /* get picture */
-    data = export_RGB_active_buffer(ctx, 1);
+    data = export_BGR_active_buffer(ctx, 1);
 
     memset(&buff, '\0', MAXLEN+1);
     g_snprintf(buff, MAXLEN, "P6  %d %d 255\n", WIDTH, HEIGHT);
@@ -96,5 +96,7 @@ run(Context_t *ctx)
       fprintf(stderr, "[!] RTMP:write_image: short write (%d of %li)\n", (int)res, RGB_BUFFSIZE);
       exit(1);
     }
+
+    fflush(rtmp);
   }
 }
