@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2012 Olivier Girondel
+ *  Copyright 1994-2013 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -40,7 +40,7 @@ char proto = PROTOCOL;
 u_long id = 1216486988;
 u_long options = BE_NONE;
 
-#define EDEBUG 1
+#define EDEBUG
 
 /* TODO: when we do not USE_FILE,
    remove xfwrite from protocols < v6 */
@@ -82,11 +82,11 @@ create(__attribute__ ((unused)) Context_t *ctx)
   env = getenv("BINIOU_ERLANG_PROTO");
   if (NULL != env) {
     char v = env[0];
-    if ((v < '1') || (v > MAX_PROTOCOL)) {
-      printf("[!] Unknown protocol version '%c', setting to %d\n", v, PROTOCOL);
+    if ((v < '0') || (v > MAX_PROTOCOL)) {
+      VERBOSE(printf("[!] Unknown protocol version '%c', setting to %d\n", v, PROTOCOL));
       proto = PROTOCOL;
     } else {
-      printf("[i] erlang: setting protocol to %c\n", v);
+      VERBOSE(printf("[i] erlang: setting protocol to %c\n", v));
       proto = v;
     }
   }
@@ -197,6 +197,7 @@ _info(const char *fmt, ...)
 void
 info(const char *fmt, ...)
 {
+#ifdef EDEBUG
   char buf[BUFLEN+1];
   uint32_t proto = 7, proto2;
   uint32_t total, total2;
@@ -204,13 +205,12 @@ info(const char *fmt, ...)
   uint32_t len;
   va_list ap;
 
-#if EDEBUG
   memset((void *)&buf, 0, (BUFLEN+1)*sizeof(char));
   va_start(ap, fmt);
   vsnprintf(buf, BUFLEN, fmt, ap);
   va_end(ap);
 
-  _info("%s\n", buf);
+  _info("%s\r\n", buf);
 
   len = strlen(buf);
 
