@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2012 Olivier Girondel
+ *  Copyright 1994-2013 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -56,8 +56,8 @@ Colormaps_new(const char *directoryname)
 
   dir = opendir(directoryname);
   if (dir == NULL) {
-    printf("[!] Error while reading colormaps directory content: %s\n",
-	   strerror(errno));
+    fprintf(stderr, "[!] Error while reading colormaps directory content: %s\n",
+	    strerror(errno));
     goto error;
   }
 
@@ -121,8 +121,7 @@ Colormaps_new(const char *directoryname)
     xperror("closedir");
 
   colormaps = xcalloc(1, sizeof(Colormaps_t));
-  if (libbiniou_verbose)
-    printf("done.\n[c] Loaded %d colormaps\n", size);
+  VERBOSE(printf("done.\n[c] Loaded %d colormaps\n", size));
 
   if (size) {
     uint16_t i;
@@ -215,7 +214,7 @@ Colormaps_find(const char *name)
     if (!strcmp(colormaps->cmaps[i]->name, name))
       return colormaps->cmaps[i]->id;
 
-  printf("[!] Colormap '%s' not found\n", name);
+  fprintf(stderr, "[!] Colormap '%s' not found\n", name);
   return colormaps->cmaps[0]->id; /* Use the first colormap by default */
 }
 
