@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2012 Olivier Girondel
+ *  Copyright 1994-2013 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -176,7 +176,7 @@ Context_new()
     int res;
 
     tmp = g_strdup_printf("%s/%s", data_dir, "/images/zebulon/z-biniou-tv-1.png");
-    printf("[+] Loading '%s'\n", tmp);
+    VERBOSE(printf("[+] Loading '%s'\n", tmp));
     res = Picture8_load_PNG(ctx->target_pic, tmp);
     assert(!res);
     if (res == -1)
@@ -186,7 +186,7 @@ Context_new()
 #endif
 
 #ifdef WITH_WEBCAM
-  printf("[i] Initialiazing %d webcams base: %s\n", webcams, video_base);
+  VERBOSE(printf("[i] Initialazing %d webcams base: %s\n", webcams, video_base));
 
   ctx->cam = 0;
   Context_open_webcam(ctx);
