@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2012 Olivier Girondel
+ *  Copyright 1994-2013 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -222,9 +222,14 @@ pop_buffer(const Context_t *ctx)
 
 /* TODO: deprecate export_RGB*, use export RGBA* */
 Pixel_t *export_RGB_buffer(const Context_t *, const u_char, const u_char);
+Pixel_t *export_BGR_buffer(const Context_t *, const u_char, const u_char);
+
 Pixel_t *export_RGB_active_buffer(const Context_t *, const u_char);
+Pixel_t *export_BGR_active_buffer(const Context_t *, const u_char);
+
 Pixel_t *export_YUV_buffer(const Context_t *, const u_char, const u_char);
 Pixel_t *export_YUV_active_buffer(const Context_t *, const u_char);
+
 const RGBA_t *export_RGBA_buffer(const Context_t *, const u_char);
 const RGBA_t *export_RGBA_active_buffer(const Context_t *);
 
