@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2012 Olivier Girondel
+ *  Copyright 1994-2013 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -100,6 +100,9 @@ Context_load_banks(Context_t *ctx)
   char *filename;
   xmlNodePtr node = NULL, bank_node = NULL;
   int m, i, j;
+  int res;
+  struct stat dummy;
+
 
   for (m = 0; m < 3; m++)
     for (i = 0; i < MAX_BANKS; i++)
@@ -109,6 +112,10 @@ Context_load_banks(Context_t *ctx)
   home_dir = g_get_home_dir();
   filename = g_strdup_printf("%s/." PACKAGE_NAME "/banks.xml", home_dir);
 
+  res = stat(filename, &dummy);
+  if (-1 == res)
+    return;
+
   /* BLA ! */
   xmlKeepBlanksDefault(0);
   xmlSubstituteEntitiesDefault(1);
