@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2012 Olivier Girondel
+ *  Copyright 1994-2013 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -53,7 +53,6 @@ Input_new(const u_short size)
 #ifdef THREAD_PLAN
   pthread_t fftw_thread; 
 #endif
-  char *pipe_name = NULL;
 
   Input_t *input = xcalloc(1, sizeof(Input_t));
 
@@ -63,16 +62,8 @@ Input_new(const u_short size)
   input->mute = 0;
   input->spectrum_size = input->size / 2 + 1;
 
-  printf("[w] data size= %d, power spectrum size= %d\n",
-	 input->size, input->spectrum_size);
-
-  if (NULL != (pipe_name = getenv("BINIOU_AUDIO_PIPE"))) {
-    input->raw = xcalloc(2*size, sizeof(int16_t));
-    input->pipe = open(pipe_name, O_WRONLY);
-    if (-1 == input->pipe)
-      xperror("open");
-  } else
-    input->pipe = -1;
+  VERBOSE(printf("[w] data size= %d, power spectrum size= %d\n",
+		 input->size, input->spectrum_size));
 
   for (c = 0; c < 3; c++) {
     /* FIXME breaks when compiling without libFFTW */
@@ -116,9 +107,6 @@ Input_delete(Input_t *input)
     fftw_destroy_plan(input->plan_fft[c]);
   }
 
-  if (-1 != input->pipe)
-    close(input->pipe);
-  xfree(input->raw);
   xfree(input);
 }
 
@@ -129,7 +117,7 @@ Input_rfftw_create_plan_threaded(void *huhu)
   Input_t *input = (Input_t *)huhu;
 
   Input_rfftw_create_plan(input);
-  printf("[i] FFTW plan created\n");
+  VERBOSE(printf("[i] FFTW plan created\n"));
 
   pthread_exit(NULL);
 }
@@ -194,7 +182,7 @@ Input_do_fft(Input_t *input)
     input->max_spectrum_log[c] = input->spectrum_log[c][new_max];
     input->max_spectrum_log_norme[c] = input->spectrum_log_norme[c][new_max];
 
-#if 0 /* def DEBUG */
+#ifdef XDEBUG
     printf("[s] Spectrum: max on channel %d\n"
 	   "[s]   spectrum: %f\n"
 	   "[s]   spectrum_norme: %f\n"
@@ -261,18 +249,6 @@ Input_set(Input_t *input, u_char mode)
 
   Input_do_fft(input);
 
-  if (NULL != input->raw) { /* Write to pipe */
-    ssize_t ret, len;
-
-    for (i = 0, j = 0; i < input->size; i++) {
-      input->raw[j++] = input->data[A_LEFT][i] * INT16_MAX;
-      input->raw[j++] = input->data[A_RIGHT][i] * INT16_MAX;
-    }
-    len = 2*input->size*sizeof(int16_t);
-    ret = write(input->pipe, (const void *)input->raw, len);
-    if (ret != len)
-      xerror("Audio pipe: short write (%d of %d)\n", ret, len);
-  }
   pthread_mutex_unlock(&input->mutex);
 }
 
