@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2012 Olivier Girondel
+ *  Copyright 1994-2013 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -42,10 +42,6 @@ typedef struct Input_s {
   /* you can also mute the input  */
   u_char  mute;
 
-  /* raw input data (usually something like s16le stereo */
-  int16_t *raw;
-  int pipe;
-
   /* Write raw input data here then call Input_set(...) */
   /* the input data, [-1..1] */
   double *data[3];
