@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2012 Olivier Girondel
+ *  Copyright 1994-2013 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -109,5 +109,5 @@ LayerMode_to_OSD_string(const enum LayerMode mode) {
     return "???";
   else
     return
-      "---\0NOR\0OVL\0XOR\0AVG\0RND\0" + 4*mode*sizeof(char);
+      &"---\0NOR\0OVL\0XOR\0AVG\0RND\0"[4*mode*sizeof(char)];
 }
