@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2012 Olivier Girondel
+ *  Copyright 1994-2013 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -61,7 +61,7 @@ char *video_base = NULL;
 static inline void
 do_banner(void)
 {
-  printf(_BANNER);
+  VERBOSE(printf(_BANNER));
 }
 
 
