@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2012 Olivier Girondel
+ *  Copyright 1994-2013 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -21,15 +21,7 @@
 #define __MAIN_H
 
 #include "biniou.h"
-
-
-#define DEFAULT_WIDTH  640
-#define DEFAULT_HEIGHT 480
-
-#define DEFAULT_DATADIR	        TO_STRING(DATADIR)
-#define DEFAULT_BASEDIR	        TO_STRING(BASEDIR)
-#define DEFAULT_SCHEMES_FILE    TO_STRING(SCHEMES_FILE)
-
+#include "defaults.h"
 
 extern char *data_dir;
 extern char *base_dir;
