@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2012 Olivier Girondel
+ *  Copyright 1994-2013 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -66,7 +66,7 @@ Pictures_new(const char *basedir, const char *themes)
     char *directoryname;
     char *th = *theme;
 
-    printf("[+] Loading theme '%s': ", th);
+    VERBOSE(printf("[+] Loading theme '%s': ", th));
     fflush(stdout);
     if (*th == '~') {
       th++;
@@ -129,7 +129,7 @@ Pictures_new(const char *basedir, const char *themes)
     if (closedir(dir) == -1)
       xperror("closedir");
     g_free(directoryname);
-    printf("done.\n");
+    VERBOSE(printf("done.\n"));
   }
 
   g_strfreev(tokens);
@@ -137,7 +137,7 @@ Pictures_new(const char *basedir, const char *themes)
   pictures = xmalloc(sizeof(Pictures_t));
   if (libbiniou_verbose) {
     pbar_delete(pb);
-    printf("[p] Loaded %d pictures\n", size);
+    VERBOSE(printf("[p] Loaded %d pictures\n", size));
   }
 
   if (size) {
@@ -181,7 +181,7 @@ Pictures_name(const uint32_t id)
   uint16_t i;
   
   if (pictures == NULL) {
-    printf("[!] No pictures loaded\n");
+    VERBOSE(fprintf(stderr, "[!] No pictures loaded\n"));
     return NULL;
   }
   
@@ -192,7 +192,7 @@ Pictures_name(const uint32_t id)
   if (id == 0)
     return pictures->pics[0]->dname;
 
-  printf("[!] Pictures_name: id %"PRIu16" not found\n", id);
+  VERBOSE(fprintf(stderr, "[!] Pictures_name: id %"PRIu16" not found\n", id));
 
   return NULL;
 }
@@ -204,7 +204,7 @@ Pictures_index(const uint32_t id)
   uint16_t i;
   
   if (pictures == NULL) {
-    printf("[!] No pictures loaded\n");
+    fprintf(stderr, "[!] No pictures loaded\n");
     return -1;
   }
   
@@ -212,7 +212,7 @@ Pictures_index(const uint32_t id)
     if (pictures->pics[i]->id == id)
       return i;
 
-  printf("[!] Pictures_index: id %"PRIu16" not found\n", id);
+  VERBOSE(fprintf(stderr, "[!] Pictures_index: id %"PRIu16" not found\n", id));
 
   return -1;
 }
@@ -224,7 +224,7 @@ Pictures_find(const char *name)
   uint16_t i;
 
   if (pictures == NULL) {
-    printf("[!] No pictures loaded\n");
+    fprintf(stderr, "[!] No pictures loaded\n");
     return 0;
   }
   
@@ -232,7 +232,8 @@ Pictures_find(const char *name)
     if (!strcmp(pictures->pics[i]->dname, name))
       return pictures->pics[i]->id;
 
-  printf("[!] Picture '%s' not found\n", name);
+  VERBOSE(fprintf(stderr, "[!] Picture '%s' not found\n", name));
+
   return pictures->pics[0]->id; /* Use the first picture by default */
 }
 
