@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2012 Olivier Girondel
+ *  Copyright 1994-2013 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -51,16 +51,14 @@ Plugin_load(Plugin_t *p)
 	
   if (p->handle == NULL) {
     error = dlerror();
-    fprintf(stderr, "[!] Failed to load plugin '%s': %s\n",
-	    p->name, error);
+    VERBOSE(fprintf(stderr, "[!] Failed to load plugin '%s': %s\n", p->name, error));
     xfree(p->name);
     xfree(p->file);
     xfree(p);
 
     return NULL;
   } else {
-    if (libbiniou_verbose)
-      printf("[p] Loading plugin '%s'", p->name);
+    VERBOSE(printf("[p] Loading plugin '%s'", p->name));
   }
   fflush(stdout);
 
@@ -148,8 +146,7 @@ Plugin_unload(Plugin_t *p)
 
   dlclose(p->handle);
 
-  if (libbiniou_verbose)
-    printf("done.\n");
+  VERBOSE(printf("done.\n"));
 }
 
 
@@ -192,8 +189,7 @@ Plugin_reload(Plugin_t *p)
   assert(p != NULL);
   Plugin_unload(p);
   Plugin_load(p);
-  if (libbiniou_verbose)
-    printf("[p] Reloaded plugin '%s'\n", p->name);
+  VERBOSE(printf("[p] Reloaded plugin '%s'\n", p->name));
 }
 
 
@@ -203,15 +199,13 @@ Plugin_init(Plugin_t *p)
   assert(p != NULL);
 
   if (p->create != NULL) {
-    if (libbiniou_verbose)
-      printf("[+] Initializing plugin %s\n", p->name);
+    VERBOSE(printf("[+] Initializing plugin %s\n", p->name));
     p->create(context);
   }
 
   if (p->jthread != NULL) {
     pthread_create(&p->thread, NULL, p->jthread, (void *)context);
-    if (libbiniou_verbose)
-      printf("[p] Launched thread %s\n", p->name);
+    VERBOSE(printf("[p] Launched thread %s\n", p->name));
   }
 }
 
