@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2012 Olivier Girondel
+ *  Copyright 1994-2013 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -122,8 +122,7 @@ Sequence_delete(Sequence_t *s)
   if (s != NULL) {
     GList *tmp;
 
-    if (libbiniou_verbose)
-      printf("[s] Freeing sequence id %"PRIu32"\n", s->id);
+    VERBOSE(printf("[s] Freeing sequence id %"PRIu32"\n", s->id));
 
     tmp = s->layers;
     while (tmp != NULL) {
@@ -152,18 +151,19 @@ Sequence_display(const Sequence_t *s)
 
   if (s == NULL)
     xerror("Attempt to display a NULL Sequence\n");
-  else
-    printf("[s] Sequence id: %"PRIu32"\n", s->id);
+  else {
+    VERBOSE(printf("[s] Sequence id: %"PRIu32"\n", s->id));
+  }
 
-  printf("[s] Name: %s\n", (s->name != NULL) ? s->name : "(none)");
+  VERBOSE(printf("[s] Name: %s\n", (s->name != NULL) ? s->name : "(none)"));
 
   if (pictures != NULL) {
     pict_name = (s->picture_id != 0) ? Pictures_name(s->picture_id) : "default";
-    printf("[s] Picture: %s\n", pict_name);
+    VERBOSE(printf("[s] Picture: %s\n", pict_name));
   }
 
   cmap_name = (s->cmap_id != 0) ? Colormaps_name(s->cmap_id) : "default";
-  printf("[s] Colormap: %s\n", cmap_name);
+  VERBOSE(printf("[s] Colormap: %s\n", cmap_name));
 
   for (tmp = g_list_first(s->layers); tmp != NULL; tmp = g_list_next(tmp)) {
     Layer_t *layer = (Layer_t *)tmp->data;
@@ -172,12 +172,14 @@ Sequence_display(const Sequence_t *s)
     if (P != NULL) {
       if ((s->lens != NULL) && (P == s->lens)) {
 	if (!after_lens) {
-	  printf("--- %s\n", P->name);
+	  VERBOSE(printf("--- %s\n", P->name));
 	  after_lens = 1;
-	} else
-	  printf("   %s\n", P->name);
-      } else
-	printf(" |  %s\n", P->name);
+	} else {
+	  VERBOSE(printf("   %s\n", P->name));
+	}
+      } else {
+	VERBOSE(printf(" |  %s\n", P->name));
+      }
     } else
       xerror("Oops got a NULL plugin\n");
   }
