@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2012 Olivier Girondel
+ *  Copyright 1994-2013 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -41,10 +41,8 @@ Sequence_load(const char *file)
   xmlChar *youhou;
   const gchar *home_dir = NULL;
 
-  if (file == NULL) {
-    printf("[!] Attempt to load a sequence with a NULL filename\n");
-    return NULL;
-  }
+  if (file == NULL)
+    xerror("Attempt to load a sequence with a NULL filename\n");
 
   dot = strrchr(file, '.');
   if ((dot == NULL) || strcasecmp(dot, ".xml")) {
@@ -70,20 +68,18 @@ Sequence_load(const char *file)
 
   doc = xmlParseFile(blah);
   g_free(blah);
-  if (doc == NULL) {
-    printf("[!] xmlParseFile error\n");
-    return NULL;
-  }
+  if (doc == NULL)
+    xerror("xmlParseFile error\n");
   
   sequence_node = xmlDocGetRootElement(doc);
   if (sequence_node == NULL) {
-    printf("[!] Sequence %s: xmlDocGetRootElement error\n", file);
+    VERBOSE(printf("[!] Sequence %s: xmlDocGetRootElement error\n", file));
     goto error;
   }
 
   sequence_node = xmlFindElement("sequence", sequence_node);
   if (sequence_node == NULL) {
-    printf("[!] Sequence %s: no <sequence> found\n", file);
+    VERBOSE(printf("[!] Sequence %s: no <sequence> found\n", file));
     goto error;
   }
 
@@ -99,7 +95,7 @@ Sequence_load(const char *file)
 
   sequence_node = xmlFindElement("auto_colormaps", sequence_node);
   if (sequence_node == NULL) {
-    printf("[!] Sequence %s: no <auto_colormaps> found\n", file);
+    VERBOSE(printf("[!] Sequence %s: no <auto_colormaps> found\n", file));
     goto error;
   }
   res = xmlGetOptionalLong(doc, sequence_node, &tmp);
@@ -127,7 +123,7 @@ Sequence_load(const char *file)
   sequence_node = sequence_node->next;
   sequence_node = xmlFindElement("auto_pictures", sequence_node);
   if (sequence_node == NULL) {
-    printf("[!] Sequence %s: no <auto_pictures> found\n", file);
+    VERBOSE(printf("[!] Sequence %s: no <auto_pictures> found\n", file));
     goto error;
   }
   res = xmlGetOptionalLong(doc, sequence_node, &tmp);
@@ -147,15 +143,13 @@ Sequence_load(const char *file)
     printf("[i] Need picture: '%s'\n", picture);
 #endif
     if (pictures == NULL) {
-      if (libbiniou_verbose)
-	printf("[!] No pictures are loaded, won't find '%s'\n", picture);
+      VERBOSE(printf("[!] No pictures are loaded, won't find '%s'\n", picture));
       xfree(picture);
       goto error;
     } else {
       s->picture_id = Pictures_find(picture);
       if (s->picture_id == 0) {
-	if (libbiniou_verbose)
-	  printf("[!] Picture '%s' not found, using default\n", picture);
+	VERBOSE(printf("[!] Picture '%s' not found, using default\n", picture));
       }
       xfree(picture);
     }
@@ -171,12 +165,12 @@ Sequence_load(const char *file)
   /* now, get plugins */
   plugins_node = xmlFindElement("plugins", sequence_node);
   if (plugins_node == NULL) {
-    printf("[!] Sequence %s: no <plugins> found\n", file);
+    VERBOSE(printf("[!] Sequence %s: no <plugins> found\n", file));
     goto error;
   }
   plugins_node = plugins_node->xmlChildrenNode;
   if (plugins_node == NULL) {
-    printf("[!] Sequence %s: no elements in <plugins>\n", file);
+    VERBOSE(printf("[!] Sequence %s: no elements in <plugins>\n", file));
     goto error;
   }
 
@@ -251,7 +245,7 @@ Sequence_load(const char *file)
   return s;
 
  error:
-  printf("[!] Failed to load sequence from file '%s'\n", file);
+  VERBOSE(printf("[!] Failed to load sequence from file '%s'\n", file));
 
   /* Clean up */
   xmlFreeDoc(doc);
