@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2012 Olivier Girondel
+ *  Copyright 1994-2013 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -76,28 +76,30 @@ Shuffler_display(const Shuffler_t *s)
   if (!libbiniou_verbose)
     return;
 
-  printf("[S] Shuffler(%d): Available= [", s->size);
+  VERBOSE(printf("[S] Shuffler(%d): Available= [", s->size));
   for (c = 0; c < s->size; c++) {
     if (!s->used[c] && !s->disabled[c]) {
-      if (one)
-	printf(", ");
-      printf("%d", c);
+      if (one) {
+	VERBOSE(printf(", "));
+      }
+      VERBOSE(printf("%d", c));
       one = 1;
     }
   }
-  printf("]\n");
+  VERBOSE(printf("]\n"));
 
   one = 0;
-  printf("[S] Shuffler: Disabled= [");
+  VERBOSE(printf("[S] Shuffler: Disabled= ["));
   for (c = 0; c < s->size; c++) {
     if (s->disabled[c]) {
-      if (one)
-	printf(", ");
-      printf("%d", c);
+      if (one) {
+	VERBOSE(printf(", "));
+      }
+      VERBOSE(printf("%d", c));
       one = 1;
     }
   }
-  printf("]\n");
+  VERBOSE(printf("]\n"));
 }
 
 
@@ -158,8 +160,9 @@ Shuffler_clean(Shuffler_t *s)
   for (c = 0; (c < s->size) && (s->used[c] || s->disabled[c]); c++);
 
   if (c == s->size) {
-    if (s->verbose)
-      printf("[S] Shuffler_clean(%p)\n", s);
+    if (s->verbose) {
+      VERBOSE(printf("[S] Shuffler_clean(%p)\n", s));
+    }
     memset((void *)s->used, 0, s->size*sizeof(char));
   }
 }
@@ -178,7 +181,7 @@ Shuffler_get(Shuffler_t *s)
 
   switch (s->mode) {
   case BS_NONE:
-    printf("[!] WARNING tried to get a value from a shuffler in BS_NONE mode\n");
+    VERBOSE(printf("[!] WARNING tried to get a value from a shuffler in BS_NONE mode\n"));
     new = 0;
     break;
 
@@ -200,7 +203,7 @@ Shuffler_get(Shuffler_t *s)
   }
 
   if (s->verbose) {
-    printf("[S] Shuffler_get(%p): %d\n", s, new);
+    VERBOSE(printf("[S] Shuffler_get(%p): %d\n", s, new));
     Shuffler_display(s);
   }
   Shuffler_clean(s);
@@ -225,7 +228,7 @@ Shuffler_next_mode(Shuffler_t *s)
 
   s->mode = (enum ShufflerMode)((s->mode+1) & 2);
   /* TODO human printable shuffler mode (None, Shuffle, ...) */
-  printf("[S] Shuffler mode set to: %d\n", (int)s->mode);
+  VERBOSE(printf("[S] Shuffler mode set to: %d\n", (int)s->mode));
 }
 
 
