@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2012 Olivier Girondel
+ *  Copyright 1994-2013 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -32,9 +32,9 @@ enumerate_menu(const webcam_t *cam)
   for (querymenu.index = queryctrl.minimum;
        querymenu.index <= (unsigned)queryctrl.maximum;
        querymenu.index++)
-    if (0 == ioctl(cam->fd, VIDIOC_QUERYMENU, &querymenu))
-      printf ("[i]   - %s\n", querymenu.name);
-    else
+    if (0 == ioctl(cam->fd, VIDIOC_QUERYMENU, &querymenu)) {
+      VERBOSE(printf ("[i]   - %s\n", querymenu.name));
+    } else
       xperror("VIDIOC_QUERYMENU");
 }
 
@@ -51,7 +51,7 @@ enumerate_base_cids(const webcam_t *cam)
       if (queryctrl.flags & V4L2_CTRL_FLAG_DISABLED)
 	continue;
       
-      printf("[i] * %s\n", queryctrl.name);
+      VERBOSE(printf("[i] * %s\n", queryctrl.name));
       
       if (queryctrl.type == V4L2_CTRL_TYPE_MENU)
 	enumerate_menu(cam);
@@ -77,7 +77,7 @@ enumerate_private_cids(webcam_t *cam)
       if (queryctrl.flags & V4L2_CTRL_FLAG_DISABLED)
 	continue;
       
-      printf ("[i] * %s\n", queryctrl.name);
+      VERBOSE(printf ("[i] * %s\n", queryctrl.name));
       
       if (queryctrl.type == V4L2_CTRL_TYPE_MENU)
 	enumerate_menu(cam);
@@ -94,9 +94,9 @@ enumerate_private_cids(webcam_t *cam)
 void
 enumerate_cids(webcam_t *cam)
 {
-  printf("[i] Webcam %d: base controls\n", cam->cam_no);
+  VERBOSE(printf("[i] Webcam %d: base controls\n", cam->cam_no));
   enumerate_base_cids(cam);
-  printf("[i] Webcam %d: private controls\n", cam->cam_no);
+  VERBOSE(printf("[i] Webcam %d: private controls\n", cam->cam_no));
   enumerate_private_cids(cam);
 }
 
@@ -114,11 +114,11 @@ set_ctrl(int fd, const int ctrl, const int value)
     if (errno != EINVAL) {
       xerror("VIDIOC_QUERYCTRL\n");
     } else {
-      printf("V4L2_CID_BRIGHTNESS is not supported\n");
+      fprintf(stderr, "V4L2_CID_BRIGHTNESS is not supported\n");
     }
   } else if (queryctrl.flags & V4L2_CTRL_FLAG_DISABLED) {
-    printf("%s is not supported\n",
-	   (ctrl == V4L2_CID_VFLIP) ? "V4L2_CID_VFLIP" : "V4L2_CID_HFLIP");
+    fprintf(stderr, "%s is not supported\n",
+	    (ctrl == V4L2_CID_VFLIP) ? "V4L2_CID_VFLIP" : "V4L2_CID_HFLIP");
   } else {
     memset(&control, 0, sizeof(control));
     control.id = ctrl;
@@ -129,9 +129,9 @@ set_ctrl(int fd, const int ctrl, const int value)
     }
   }
 
-  printf("[i] %s: default= %d",
-	 ((ctrl == V4L2_CID_VFLIP) ? "V4L2_CID_VFLIP" : "V4L2_CID_HFLIP"),
-	 control.value);;
+  VERBOSE(printf("[i] %s: default= %d",
+		 ((ctrl == V4L2_CID_VFLIP) ? "V4L2_CID_VFLIP" : "V4L2_CID_HFLIP"),
+		 control.value));
 
   memset(&control, 0, sizeof (control));
   control.id = ctrl;
@@ -143,7 +143,7 @@ set_ctrl(int fd, const int ctrl, const int value)
 	&& errno != ERANGE) {
       xerror("VIDIOC_S_CTRL\n");
     } else
-      printf(" set: %d\n", value);
+      VERBOSE(printf(" set: %d\n", value));
     /* Ignore if V4L2_CID_CONTRAST is unsupported */
   } else if (errno != EINVAL) {
     xerror("VIDIOC_G_CTRL\n");
@@ -174,18 +174,18 @@ list_inputs(const webcam_t *cam)
 
   inputs.index = 0;
   while (ioctl(fd, VIDIOC_ENUMINPUT, &inputs) == 0) {
-    printf("[i] Webcam %d: input #%d\n", cam->cam_no, index);
-    printf("[i] * Name: %s\n", inputs.name);
+    VERBOSE(printf("[i] Webcam %d: input #%d\n", cam->cam_no, index));
+    VERBOSE(printf("[i] * Name: %s\n", inputs.name));
 
-    printf("[i] * Type: ");
-    if (inputs.type == V4L2_INPUT_TYPE_CAMERA)
-      printf("camera\n");
-    else if (inputs.type == V4L2_INPUT_TYPE_TUNER)
-      printf("tuner\n");
-    else
+    VERBOSE(printf("[i] * Type: "));
+    if (inputs.type == V4L2_INPUT_TYPE_CAMERA) {
+      VERBOSE(printf("camera\n"));
+    } else if (inputs.type == V4L2_INPUT_TYPE_TUNER) {
+      VERBOSE(printf("tuner\n"));
+    } else
       assert(0);
 
-    printf("[i] * Video standard: %d\n", (int)inputs.std);
+    VERBOSE(printf("[i] * Video standard: %d\n", (int)inputs.std));
     index++;
     inputs.index = index;
   }
