@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2012 Olivier Girondel
+ *  Copyright 1994-2013 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -37,18 +37,18 @@ process_token(const char *tok)
     vv++;
     assert(NULL != *vv);
     webcams = xatol(*vv);
-    printf("[E] webcam: grabbing %d device%s\n", webcams, (webcams == 1) ? "" : "s");
+    VERBOSE(printf("[E] webcam: grabbing %d device%s\n", webcams, (webcams == 1) ? "" : "s"));
   } if (!strcmp((const char *)*vv, "device")) {
     vv++;
     assert(NULL != *vv);
-    printf("[E] webcam: device set to %s\n", *vv);
+    VERBOSE(printf("[E] webcam: device set to %s\n", *vv));
     free(video_base);
     video_base = strdup(*vv);
   } else if (!strcmp((const char *)*vv, "hflip")) {
-    printf("[E] webcam: set horizontal flip\n");
+    VERBOSE(printf("[E] webcam: set horizontal flip\n"));
     hflip = !hflip;
   } else if (!strcmp((const char *)*vv, "vflip")) {
-    printf("[E] webcam: set vertical flip\n");
+    VERBOSE(printf("[E] webcam: set vertical flip\n"));
     vflip = !vflip;
   }
 
